define('dojo/nls/pmbdijit_fi-fi',{
'dijit/nls/loading':{"loadingState":"Lataus on meneillään...","errorState":"On ilmennyt virhe.","_localized":{}}
,
'dijit/form/nls/validate':{"invalidMessage":"Annettu arvo ei kelpaa.","missingMessage":"Tämä arvo on pakollinen.","rangeMessage":"Tämä arvo on sallitun alueen ulkopuolella.","_localized":{}}
,
'dojo/cldr/nls/number':{"scientificFormat":"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]","infinity":"∞","superscriptingExponent":"×","list":";","percentSign":"%","minusSign":"−","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000 bilj'.'","currencySpacing-afterCurrency-insertBetween":" ","nan":"epäluku","plusSign":"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]","currencyFormat":"#,##0.00 ¤","perMille":"‰","group":" ","percentFormat":"#,##0 %","decimalFormat-long":"000 biljoonaa","decimalFormat":"#,##0.###","decimal":",","currencySpacing-beforeCurrency-insertBetween":" ","exponential":"E","_localized":{}}
,
'dijit/nls/common':{"buttonOk":"OK","buttonCancel":"Peruuta","buttonSave":"Tallenna","itemClose":"Sulje","_localized":{}}
,
'dijit/_editor/nls/commands':{"bold":"Lihavointi","copy":"Kopioi","cut":"Leikkaa","delete":"Poista","indent":"Sisennä","insertHorizontalRule":"Vaakasuuntainen viiva","insertOrderedList":"Numeroitu luettelo","insertUnorderedList":"Numeroimaton luettelo","italic":"Kursivointi","justifyCenter":"Tasaus keskelle","justifyFull":"Tasaus","justifyLeft":"Tasaus vasemmalle","justifyRight":"Tasaus oikealle","outdent":"Ulonna","paste":"Liitä","redo":"Tee uudelleen","removeFormat":"Poista muotoilu","selectAll":"Valitse kaikki","strikethrough":"Yliviivaus","subscript":"Alennettu","superscript":"Korotettu","underline":"Alleviivaus","undo":"Kumoa","unlink":"Poista linkki","createLink":"Luo linkki","toggleDir":"Vaihda suuntaa","insertImage":"Lisää kuva","insertTable":"Lisää taulukko/muokkaa taulukkoa","toggleTableBorder":"Ota taulukon kehys käyttöön/poista kehys käytöstä","deleteTable":"Poista taulukko","tableProp":"Taulukon ominaisuudet","htmlToggle":"HTML-lähde","foreColor":"Edustaväri","hiliteColor":"Taustaväri","plainFormatBlock":"Kappaletyyli","formatBlock":"Kappaletyyli","fontSize":"Fonttikoko","fontName":"Fontin nimi","tabIndent":"Sarkainsisennys","fullScreen":"Vaihda koko näyttö","viewSource":"Näytä HTML-lähde","print":"Tulosta","newPage":"Uusi sivu","systemShortcut":"Toiminto \"${0}\" on käytettävissä selaimessa vain näppäimistön pikatoiminnolla. Käytä seuraavaa: ${1}.","ctrlKey":"Ctrl+${0}","appleKey":"⌘${0}","_localized":{}}
,
'dijit/form/nls/ComboBox':{"previousMessage":"Edelliset valinnat","nextMessage":"Lisää valintoja","_localized":{}}
,
'dijit/_editor/nls/FontChoice':{"1":"xx-small","2":"x-small","3":"small","4":"medium","5":"large","6":"x-large","7":"xx-large","fontSize":"Koko","fontName":"Fontti","formatBlock":"Muotoile","serif":"serif","sans-serif":"sans-serif","monospace":"monospace","cursive":"cursive","fantasy":"fantasy","noFormat":"Ei mitään","p":"Kappale","h1":"Otsikko","h2":"Alatason otsikko","h3":"Alimman tason otsikko","pre":"Esimuotoiltu","_localized":{}}
,
'dojox/editor/plugins/nls/latinEntities':{"iexcl":"ylösalainen huutomerkki","cent":"sentin merkki","pound":"punnan merkki","curren":"valuuttamerkki","yen":"jenin merkki\nyuanin merkki","brvbar":"katkopystyviiva","sect":"pykälämerkki","uml":"treema\ntilaa vievä treema","copy":"tekijänoikeusmerkki","ordf":"feminiinisen järjestysluvun merkki","laquo":"vasemmalle osoittava kaksinkertainen kulmalainausmerkki\nvasemmalle osoittava kulmalainausmerkki","not":"negaation merkki\nei-merkki","shy":"ehdollinen tavuviiva\npehmeä tavuviiva\ntavutusvihje","reg":"rekisteröidyn tavaramerkin merkki\nrekisteröity tavaramerkki -merkki","macr":"macron\nviiva-aksentti\npituusmerkki\npäällekkäisviiva","deg":"astemerkki","plusmn":"plus-miinus-merkki\nplus- tai miinusmerkki","sup2":"yläindeksi kaksi\nneliö\ntoinen potenssi","sup3":"yläindeksi kolme\nkuutio\nkolmas potenssi","acute":"akuutti\nakuuttiaksentti","micro":"mikro-merkki","para":"kappaleen merkki\nkappalemerkki","middot":"keskipiste\nrivinkeskinen piste\ngeorgialainen pilkku\nkreikkalainen keskipiste","cedil":"sedilji\ntilaa vievä sedilji\ncedilla","sup1":"yläindeksi yksi","ordm":"maskuliinisen järjestysluvun merkki","raquo":"oikealle osoittava kaksinkertainen kulmalainausmerkki\noikealle osoittava kulmalainausmerkki","frac14":"neljäsosan merkki\nneljäsosa","frac12":"puolikkaan merkki\npuolikas","frac34":"kolmen neljäsosan merkki\nkolme neljäsosaa","iquest":"ylösalainen kysymysmerkki","Agrave":"iso A ja gravis\nversaali A ja gravis","Aacute":"iso A ja akuutti\niso A ja akuuttiaksentti\nversaali A ja akuutti","Acirc":"iso A ja sirkumfleksi\nversaali A ja sirkumfleksi","Atilde":"iso A ja tilde\nversaali A ja tilde\niso A ja aaltoviiva\nversaali A ja aaltoviiva","Auml":"iso Ä\nversaali Ä","Aring":"iso Å\nversaali Å\niso ruotsalainen o\nversaali ruotsalainen o","AElig":"iso AE\nversaali AE\niso ligatuuri AE\nversaaliligatuuri AE\niso tanskalainen ä\nversaali tanskalainen ä","Ccedil":"iso C ja sedilji\nversaali C ja sedilji","Egrave":"iso E ja gravis\nversaali E ja gravis","Eacute":"iso E ja akuutti\niso E ja akuuttiaksentti\nversaali E ja akuutti","Ecirc":"iso E ja sirkumfleksi\nversaali E ja sirkumfleksi","Euml":"iso E ja treema\nversaali E ja treema","Igrave":"iso I ja gravis\nversaali I ja gravis","Iacute":"iso I ja akuutti\niso I ja akuuttiaksentti\nversaali I ja akuutti","Icirc":"iso I ja sirkumfleksi\nversaali I ja sirkumfleksi","Iuml":"iso I ja treema\nversaali I ja treema","ETH":"iso eth\nversaali eth","Ntilde":"iso N ja tilde\nversaali N ja tilde\niso N ja aaltoviiva\nversaali N ja aaltoviiva","Ograve":"iso O ja gravis\nversaali O ja gravis","Oacute":"iso O ja akuutti\niso O ja akuuttiaksentti\nversaali O ja akuutti","Ocirc":"iso O ja sirkumfleksi\nversaali O ja sirkumfleksi","Otilde":"iso O ja tilde\nversaali O ja tilde\niso O ja aaltoviiva\nversaali O ja aaltoviiva","Ouml":"iso O ja treema\nversaali O ja treema","times":"kertomerkki","Oslash":"iso tanskalainen ö\nversaali tanskalainen ö\niso O ja vinoviiva\nversaali O ja vinoviiva\niso O, jossa on poikkiviiva\nversaali O, jossa on poikkiviiva","Ugrave":"iso U ja gravis\nversaali U ja gravis","Uacute":"iso U ja akuutti\niso U ja akuuttiaksentti\nversaali U ja akuutti","Ucirc":"iso U ja sirkumfleksi\nversaali U ja sirkumfleksi","Uuml":"iso U ja treema\nversaali U ja treema\niso saksalainen y\nversaali saksalainen y","Yacute":"iso Y ja akuutti\niso Y ja akuuttiaksentti\nversaali Y ja akuutti","THORN":"iso thorn\nversaali thorn","szlig":"pieni kaksois-s\ngemena kaksois-s\npieni saksalainen kaksois-s\ngemena saksalainen kaksois-s","agrave":"pieni a ja gravis\ngemena a ja gravis","aacute":"pieni a ja akuutti\ngemena a ja akuutti\npieni a ja akuuttiaksentti","acirc":"pieni a ja sirkumfleksi\ngemena a ja sirkumfleksi","atilde":"pieni a ja tilde\ngemena a ja tilde\npieni a ja aaltoviiva\ngemena a ja aaltoviiva","auml":"pieni ä\ngemena ä","aring":"pieni å\ngemena å\npieni ruotsalainen o\ngemena ruotsalainen o","aelig":"pieni ae\ngemena ae\npieni ligatuuri ae\ngemenaligatuuri ae\npieni tanskalainen ä\ngemena tanskalainen ä","ccedil":"pieni c ja sedilji\ngemena c ja sedilji","egrave":"pieni e ja gravis\ngemena e ja gravis","eacute":"pieni e ja akuutti\ngemena e ja akuutti\npieni e ja akuuttiaksentti","ecirc":"pieni e ja sirkumfleksi\ngemena e ja sirkumfleksi","euml":"pieni e ja treema\ngemena e ja treema","igrave":"pieni i ja gravis\ngemena e ja gravis","iacute":"pieni i ja akuutti\ngemena i ja akuutti\npieni i ja akuuttiaksentti","icirc":"pieni i ja sirkumfleksi\ngemena i ja sirkumfleksi","iuml":"pieni i ja treema\ngemena i ja treema","eth":"pieni eth\ngemena eth","ntilde":"pieni n ja tilde\ngemena n ja tilde\npieni n ja aaltoviiva\ngemena n ja aaltoviiva","ograve":"pieni o ja gravis\ngemena o ja gravis","oacute":"pieni o ja akuutti\ngemena o ja akuutti\npieni o ja akuuttiaksentti","ocirc":"pieni o ja sirkumfleksi\ngemena o ja sirkumfleksi","otilde":"pieni o ja tilde\ngemena o ja tilde\npieni o ja aaltoviiva\ngemena o ja aaltoviiva","ouml":"pieni ö\ngemena ö","divide":"jakomerkki","oslash":"pieni tanskalainen ö\ngemena tanskalainen ö\npieni o ja vinoviiva\ngemena o ja vinoviiva\npieni o, jossa on poikkiviiva\ngemena o, jossa on poikkiviiva","ugrave":"pieni u ja gravis\ngemena u ja gravis","uacute":"pieni u ja akuutti\ngemena u ja akuutti\npieni u ja akuuttiaksentti","ucirc":"pieni u ja sirkumfleksi\ngemena u ja sirkumfleksi","uuml":"pieni u ja treema\ngemena u ja treema\npieni saksalainen y\ngemena saksalainen y","yacute":"pieni y ja akuutti\ngemena y ja akuutti\npieni y ja akuuttiaksentti","thorn":"pieni thorn\ngemena thorn","yuml":"pieni y ja treema\ngemena y ja treema","fnof":"pieni f, jossa koukku\ngemena f, jossa koukku\nfunktio\nguldeni","Alpha":"iso alfa\nversaali alfa","Beta":"iso beeta\nversaali beeta","Gamma":"iso gamma\nversaali gamma","Delta":"iso delta\nversaali delta","Epsilon":"iso epsilon\nversaali epsilon","Zeta":"iso zeeta\nversaali zeeta","Eta":"iso eeta\nversaali eeta","Theta":"iso theeta\nversaali theeta","Iota":"iso ioota\nversaali ioota","Kappa":"iso kappa\nversaali kappa","Lambda":"iso lambda\nversaali lambda","Mu":"iso myy\nversaali myy","Nu":"iso nyy\nversaali nyy","Xi":"iso ksii\nversaali ksii","Omicron":"iso omikron\nversaali omikron","Pi":"iso pii\nversaali pii","Rho":"iso rhoo\nversaali rhoo","Sigma":"iso sigma\nversaali sigma","Tau":"iso tau\nversaali tau","Upsilon":"iso ypsilon\nversaali ypsilon","Phi":"iso fii\nversaali fii","Chi":"iso khii\nversaali khii","Psi":"iso psii\nversaali psii","Omega":"iso oomega\nversaali oomega","alpha":"pieni alfa\ngemena alfa","beta":"pieni beeta\ngemena beeta","gamma":"pieni gamma\ngemena gamma","delta":"pieni delta\ngemena delta","epsilon":"pieni epsilon\ngemena epsilon","zeta":"pieni zeeta\ngemena zeeta","eta":"pieni eeta\ngemena eeta","theta":"pieni theeta\ngemena theeta","iota":"pieni ioota\ngemena ioota","kappa":"pieni kappa\ngemena kappa","lambda":"pieni lambda\ngemena lambda","mu":"pieni myy\ngemena myy","nu":"pieni nyy\ngemena nyy","xi":"pieni ksii\ngemena ksii","omicron":"pieni omikron\ngemena omikron","pi":"pieni pii\ngemena pii","rho":"pieni rhoo\ngemena rhoo","sigmaf":"pieni sananloppuinen sigma\ngemena sananloppuinen sigma","sigma":"pieni sigma\ngemena sigma","tau":"pieni tau\ngemena tau","upsilon":"pieni ypsilon\ngemena ypsilon","phi":"pieni fii\ngemena fii","chi":"pieni khii\ngemena khii","psi":"pieni psii\ngemena psii","omega":"pieni oomega\ngemena oomega","thetasym":"pieni theeta\ngemena theeta","upsih":"ypsilon, jossa koukku","piv":"pii-merkki","bull":"luetelmamerkki\nluetelmapallo\npieni musta ympyrä","hellip":"kolme pistettä\nkolme pistettä vaakasuunnassa\nellipsi","prime":"yläpuolinen indeksointipilkku\nindeksointipilkku\nminuutit\njalat","Prime":"kaksinkertainen yläpuolinen indeksointipilkku\nsekunnit\ntuumat","oline":"yläviiva","frasl":"murtoluvun vinoviiva\nmurtolukuviiva","weierp":"iso kaunokirjoitus-P\npotenssijoukko\nWeierstrassin p","image":"goottilainen iso I\ngoottilainen versaali I\nimaginaarinen osa","real":"goottilainen iso R\ngoottilainen versaali R\nreaaliosa","trade":"tavaramerkki\ntavaramerkin merkki","alefsym":"alef-merkki\nalef\nensimmäinen transfiniittinen kardinaali","larr":"vasen nuoli\nnuoli vasemmalle","uarr":"ylänuoli\nnuoli ylös\nylöspäin osoittava nuoli","rarr":"oikea nuoli\nnuoli oikealle","darr":"alanuoli\nnuoli alas\nalaspäin osoittava nuoli","harr":"nuoli vasemmalle ja oikealle","crarr":"rivinvaihtomerkki","lArr":"kaksoisnuoli vasemmalle","uArr":"kaksoisnuoli ylös","rArr":"kaksoisnuoli oikealle","dArr":"kaksoisnuoli alas","hArr":"kaksoisnuoli vasemmalle ja oikealle","forall":"kaikkikvanttori\nuniversaalikvanttori","part":"osittaisderivaatta","exist":"olemassaolokvanttori","empty":"tyhjä joukko\nhalkaisija","nabla":"nabla\ngradientti","isin":"joukkoon kuulumisen merkki","notin":"joukkoon kuulumattomuuden merkki","ni":"käänteinen joukkoon kuulumisen merkki","prod":"tulo\ntulon merkki","sum":"summa","minus":"miinusmerkki","lowast":"tähti\nasteriski","radic":"neliöjuuri\njuurimerkki","prop":"verrannollinen","infin":"ääretön\näärettömän merkki","ang":"kulma","and":"looginen ja-merkki","or":"looginen tai-merkki","cap":"leikkauksen merkki\nleikkaus","cup":"yhdisteen merkki\nyhdiste\nunioni","int":"integraalimerkki\nintegraali","there4":"loogisen seuraamuksen merkki\njoten\nsiis","sim":"tildeoperaattori\nlikiarvo","cong":"suunnilleen yhtä suuri kuin -merkki","asymp":"likimain yhtä suuri kuin -merkki\nasymptoottinen","ne":"eri suuri kuin -merkki\nerisuuruusmerkki","equiv":"identtisesti yhtä suuri kuin -merkki","le":"pienempi tai yhtä suuri kuin -merkki","ge":"suurempi tai yhtä suuri kuin -merkki","sub":"osajoukon merkki","sup":"ylijoukon merkki","nsub":"osajoukkosuhteen negaation merkki","sube":"osajoukkosuhteen tai yhtäläisyyden merkki","supe":"ylijoukkosuhteen tai yhtäläisyyden merkki","oplus":"ympyrässä oleva plusmerkki\nsuora summa","otimes":"ympyrässä oleva kertomerkki\nvektoritulo\nristitulo","perp":"kohtisuoruusmerkki","sdot":"pisteoperaattori","lceil":"vasen kattosymboli","rceil":"oikea kattosymboli","lfloor":"vasen lattiasymboli","rfloor":"oikea lattiasymboli","lang":"vasemmalle osoittava kulmasulje","rang":"oikealle osoittava kulmasulje","loz":"vinoneliö\nnelikovero","spades":"musta korttipakan pata","clubs":"musta korttipakan risti\napila","hearts":"musta korttipakan hertta\nsydän","diams":"musta korttipakan ruutu","OElig":"iso ligatuuri OE\nversaaliligatuuri OE","oelig":"pieni ligatuuri oe\ngemenaligatuuri oe","Scaron":"iso hattu-S\nversaali hattu-S","scaron":"pieni hattu-s\ngemena hattu-s","Yuml":"iso Y ja treema\nversaali Y ja treema","circ":"tarkkeenomainen sirkumfleksi","tilde":"pieni tilde","ensp":"n-väli\nn-kirjaimen levyinen väli","emsp":"m-väli\nm-kirjaimen levyinen väli","thinsp":"kapea väli","zwnj":"leveydetön erottava merkki","zwj":"leveydetön yhdistävä merkki","lrm":"vasemmalta oikealle -merkki","rlm":"oikealta vasemmalle -merkki","ndash":"n-viiva\nlyhyt ajatusviiva","mdash":"m-viiva\npitkä ajatusviiva","lsquo":"ylösalainen puolilainausmerkki","rsquo":"puolilainausmerkki","sbquo":"rivinalinen puolilainausmerkki","ldquo":"ylösalainen kokolainausmerkki","rdquo":"kokolainausmerkki","bdquo":"rivinalinen kokolainausmerkki","dagger":"risti","Dagger":"kaksoisristi","permil":"promillemerkki","lsaquo":"vasemmalle osoittava kulmapuolilainausmerkki","rsaquo":"oikealle osoittava kulmapuolilainausmerkki","euro":"euron merkki","_localized":{}}
,
'dojox/editor/plugins/nls/InsertEntity':{"insertEntity":"Lisää symboli","_localized":{}}
,
'dojo/nls/colors':{"aliceblue":"vaaleanharmaansininen","antiquewhite":"antiikinvalkoinen","aqua":"sinivihreä","aquamarine":"vedenvihreä","azure":"taivaansininen","beige":"vaaleanruskea","bisque":"vaaleanruskea","black":"musta","blanchedalmond":"kuorittu manteli","blue":"sininen","blueviolet":"sinivioletti","brown":"ruskea","burlywood":"puunruskea","cadetblue":"meren vihreä","chartreuse":"kellanvihreä","chocolate":"suklaanruskea","coral":"koralli","cornflowerblue":"syvänsininen","cornsilk":"maissinkeltainen","crimson":"karmiininpunainen","cyan":"syaani","darkblue":"tummansininen","darkcyan":"tumma turkoosi","darkgoldenrod":"tumma kultapiisku","darkgray":"tummanharmaa","darkgreen":"tummanvihreä","darkgrey":"tummanharmaa","darkkhaki":"tumma khaki","darkmagenta":"tumma magenta","darkolivegreen":"tummanoliivinvihreä","darkorange":"tummanoranssi","darkorchid":"tumma orkidea","darkred":"tummanpunainen","darksalmon":"tumma lohenpunainen","darkseagreen":"tumma merenvihreä","darkslateblue":"tumma siniharmaa","darkslategray":"tummanharmaa","darkslategrey":"tummanharmaa","darkturquoise":"tumma turkoosi","darkviolet":"tummanvioletti","deeppink":"syvä vaaleanpunainen","deepskyblue":"tumma taivaansininen","dimgray":"himmeänharmaa","dimgrey":"himmeänharmaa","dodgerblue":"Dodger-sininen","firebrick":"poltetun tiilen punainen","floralwhite":"kukanvalkoinen","forestgreen":"metsänvihreä","fuchsia":"purppura","gainsboro":"gainsboro","ghostwhite":"lakananvalkoinen","gold":"kulta","goldenrod":"kullanruskea","gray":"harmaa","green":"vihreä","greenyellow":"vihreänkeltainen","grey":"harmaa","honeydew":"hunajameloninvihreä","hotpink":"pinkki","indianred":"kirkkaanpunainen","indigo":"indigo","ivory":"norsunluu","khaki":"khaki","lavender":"laventeli","lavenderblush":"laventelinpunainen","lawngreen":"ruohonvihreä","lemonchiffon":"sitruunankeltainen","lightblue":"vaaleansininen","lightcoral":"vaalea koralli","lightcyan":"vaalea syaani","lightgoldenrodyellow":"vaalea kultapiiskunkeltainen","lightgray":"vaaleanharmaa","lightgreen":"vaaleanvihreä","lightgrey":"vaaleanharmaa","lightpink":"vaaleanpunainen","lightsalmon":"vaalea lohenpunainen","lightseagreen":"vaalea merenvihreä","lightskyblue":"vaalea taivaansininen","lightslategray":"vaaleanharmaa","lightslategrey":"vaaleanharmaa","lightsteelblue":"vaalea teräksensininen","lightyellow":"vaaleankeltainen","lime":"vaaleanvihreä","limegreen":"limetinvihreä","linen":"pellavanvaalea","magenta":"magenta","maroon":"kastanjanruskea","mediumaquamarine":"keskivaalea vedenvihreä","mediumblue":"keskisininen","mediumorchid":"keskivaalea orkidea","mediumpurple":"keskivaalea violetti","mediumseagreen":"keskivaalea merenvihreä","mediumslateblue":"keskivaalea siniharmaa","mediumspringgreen":"keskivaalea keväänvihreä","mediumturquoise":"keskivaalea turkoosi","mediumvioletred":"keskivaalea lila","midnightblue":"yönsininen","mintcream":"minttukreemi","mistyrose":"utuinen ruusu","moccasin":"nahanruskea","navajowhite":"navajonvalkoinen","navy":"laivastonsininen","oldlace":"vanha pitsi","olive":"oliivinvihreä","olivedrab":"oliivinruskea","orange":"oranssi","orangered":"oranssinpunainen","orchid":"orkidea","palegoldenrod":"haalea kultapiisku","palegreen":"haalea vihreä","paleturquoise":"haalea turkoosi","palevioletred":"haalea lila","papayawhip":"papaijavaahto","peachpuff":"persikka","peru":"peru","pink":"vaaleanpunainen","plum":"luumunpunainen","powderblue":"harmaansininen","purple":"violetti","red":"punainen","rosybrown":"punertavanruskea","royalblue":"syvänsininen","saddlebrown":"satulanruskea","salmon":"lohenpunainen","sandybrown":"hiekanruskea","seagreen":"merenvihreä","seashell":"simpukankuori","sienna":"siena","silver":"hopea","skyblue":"taivaansininen","slateblue":"savensininen","slategray":"savenharmaa","slategrey":"savenharmaa","snow":"lumivalkoinen","springgreen":"keväänvihreä","steelblue":"teräksensininen","tan":"kellanruskea","teal":"sinivihreä","thistle":"ohdake","tomato":"tomaatinpunainen","transparent":"läpinäkyvä","turquoise":"turkoosi","violet":"violetti","wheat":"vehnänkeltainen","white":"valkoinen","whitesmoke":"savunvalkea","yellow":"keltainen","yellowgreen":"kellanvihreä","_localized":{}}
,
'dojox/widget/nls/ColorPicker':{"redLabel":"r","greenLabel":"g","blueLabel":"b","hueLabel":"h","saturationLabel":"s","valueLabel":"v","degLabel":"°","hexLabel":"hex","huePickerTitle":"Sävyn valitsin","saturationPickerTitle":"Kylläisyyden valitsin","_localized":{}}
,
'dojox/editor/plugins/nls/TableDialog':{"insertTableTitle":"Lisää taulukko","modifyTableTitle":"Muokkaa taulukkoa","rows":"Rivit:","columns":"Sarakkeet:","align":"Tasaus:","cellPadding":"Solun täyttö:","cellSpacing":"Solujen väli:","tableWidth":"Taulukon leveys:","backgroundColor":"Taustaväri:","borderColor":"Kehyksen väri:","borderThickness":"Kehyksen paksuus:","percent":"prosenttia","pixels":"kuvapistettä","default":"oletus","left":"vasen","center":"keskitetty","right":"oikea","buttonSet":"Aseta","buttonInsert":"Lisää","buttonCancel":"Peruuta","selectTableLabel":"Valitse taulukko","insertTableRowBeforeLabel":"Lisää rivi ennen","insertTableRowAfterLabel":"Lisää rivi jälkeen","insertTableColumnBeforeLabel":"Lisää sarake ennen","insertTableColumnAfterLabel":"Lisää sarake jälkeen","deleteTableRowLabel":"Poista rivi","deleteTableColumnLabel":"Poista sarake","colorTableCellTitle":"Taulukon solun taustaväri","tableContextMenuTitle":"Taulukon pikavalikko","_localized":{}}
,
'dojox/editor/plugins/nls/PasteFromWord':{"pasteFromWord":"Liitä Word-ohjelmasta","instructions":"Liitä sisältö Word-tiedostosta alla olevaan tekstikenttään. Kun lisättävä sisältö on mielestäsi valmis, napsauta Liitä-painiketta. Voit peruuttaa lisäyksen napsauttamalla Peruuta-painiketta.","_localized":{}}
,
'dojox/editor/plugins/nls/InsertAnchor':{"insertAnchor":"Lisää ankkuri","title":"Ankkurin ominaisuudet","anchor":"Nimi:","text":"Kuvaus:","set":"Aseta","cancel":"Peruuta","_localized":{}}
,
'dojox/editor/plugins/nls/Blockquote':{"blockquote":"Blockquote","_localized":{}}
,
'dojox/editor/plugins/nls/LocalImage':{"insertImageTitle":"Lisää kuva","url":"Kuva","browse":"Selaa...","text":"Kuvaus","set":"Lisää","invalidMessage":"Virheellinen kuvatiedoston laji","prePopuTextUrl":"Anna kuvan URL-osoite","prePopuTextBrowse":" tai selaa paikalliseen tiedostoon.","_localized":{}}
});